/****************************************************************************
** Meta object code from reading C++ file 'qnearfieldmanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.13)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/nfc/qnearfieldmanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qnearfieldmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.13. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QNearFieldManager_t {
    QByteArrayData data[19];
    char stringdata0[280];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QNearFieldManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QNearFieldManager_t qt_meta_stringdata_QNearFieldManager = {
    {
QT_MOC_LITERAL(0, 0, 17), // "QNearFieldManager"
QT_MOC_LITERAL(1, 18, 19), // "adapterStateChanged"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 31), // "QNearFieldManager::AdapterState"
QT_MOC_LITERAL(4, 71, 5), // "state"
QT_MOC_LITERAL(5, 77, 14), // "targetDetected"
QT_MOC_LITERAL(6, 92, 17), // "QNearFieldTarget*"
QT_MOC_LITERAL(7, 110, 6), // "target"
QT_MOC_LITERAL(8, 117, 10), // "targetLost"
QT_MOC_LITERAL(9, 128, 12), // "AdapterState"
QT_MOC_LITERAL(10, 141, 7), // "Offline"
QT_MOC_LITERAL(11, 149, 9), // "TurningOn"
QT_MOC_LITERAL(12, 159, 6), // "Online"
QT_MOC_LITERAL(13, 166, 10), // "TurningOff"
QT_MOC_LITERAL(14, 177, 16), // "TargetAccessMode"
QT_MOC_LITERAL(15, 194, 14), // "NoTargetAccess"
QT_MOC_LITERAL(16, 209, 20), // "NdefReadTargetAccess"
QT_MOC_LITERAL(17, 230, 21), // "NdefWriteTargetAccess"
QT_MOC_LITERAL(18, 252, 27) // "TagTypeSpecificTargetAccess"

    },
    "QNearFieldManager\0adapterStateChanged\0"
    "\0QNearFieldManager::AdapterState\0state\0"
    "targetDetected\0QNearFieldTarget*\0"
    "target\0targetLost\0AdapterState\0Offline\0"
    "TurningOn\0Online\0TurningOff\0"
    "TargetAccessMode\0NoTargetAccess\0"
    "NdefReadTargetAccess\0NdefWriteTargetAccess\0"
    "TagTypeSpecificTargetAccess"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QNearFieldManager[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       2,   38, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   29,    2, 0x06 /* Public */,
       5,    1,   32,    2, 0x06 /* Public */,
       8,    1,   35,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, 0x80000000 | 6,    7,

 // enums: name, alias, flags, count, data
       9,    9, 0x2,    4,   48,
      14,   14, 0x0,    4,   56,

 // enum data: key, value
      10, uint(QNearFieldManager::AdapterState::Offline),
      11, uint(QNearFieldManager::AdapterState::TurningOn),
      12, uint(QNearFieldManager::AdapterState::Online),
      13, uint(QNearFieldManager::AdapterState::TurningOff),
      15, uint(QNearFieldManager::NoTargetAccess),
      16, uint(QNearFieldManager::NdefReadTargetAccess),
      17, uint(QNearFieldManager::NdefWriteTargetAccess),
      18, uint(QNearFieldManager::TagTypeSpecificTargetAccess),

       0        // eod
};

void QNearFieldManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QNearFieldManager *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->adapterStateChanged((*reinterpret_cast< QNearFieldManager::AdapterState(*)>(_a[1]))); break;
        case 1: _t->targetDetected((*reinterpret_cast< QNearFieldTarget*(*)>(_a[1]))); break;
        case 2: _t->targetLost((*reinterpret_cast< QNearFieldTarget*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QNearFieldTarget* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QNearFieldTarget* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QNearFieldManager::*)(QNearFieldManager::AdapterState );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QNearFieldManager::adapterStateChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QNearFieldManager::*)(QNearFieldTarget * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QNearFieldManager::targetDetected)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QNearFieldManager::*)(QNearFieldTarget * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QNearFieldManager::targetLost)) {
                *result = 2;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject QNearFieldManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_QNearFieldManager.data,
    qt_meta_data_QNearFieldManager,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QNearFieldManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QNearFieldManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QNearFieldManager.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QNearFieldManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void QNearFieldManager::adapterStateChanged(QNearFieldManager::AdapterState _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void QNearFieldManager::targetDetected(QNearFieldTarget * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QNearFieldManager::targetLost(QNearFieldTarget * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
