/****************************************************************************
** Meta object code from reading C++ file 'gattchar1_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.13)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/bluetooth/bluez/gattchar1_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'gattchar1_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.13. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_OrgBluezGattCharacteristic1Interface_t {
    QByteArrayData data[16];
    char stringdata0[197];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_OrgBluezGattCharacteristic1Interface_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_OrgBluezGattCharacteristic1Interface_t qt_meta_stringdata_OrgBluezGattCharacteristic1Interface = {
    {
QT_MOC_LITERAL(0, 0, 36), // "OrgBluezGattCharacteristic1In..."
QT_MOC_LITERAL(1, 37, 9), // "ReadValue"
QT_MOC_LITERAL(2, 47, 29), // "QDBusPendingReply<QByteArray>"
QT_MOC_LITERAL(3, 77, 0), // ""
QT_MOC_LITERAL(4, 78, 7), // "options"
QT_MOC_LITERAL(5, 86, 11), // "StartNotify"
QT_MOC_LITERAL(6, 98, 19), // "QDBusPendingReply<>"
QT_MOC_LITERAL(7, 118, 10), // "StopNotify"
QT_MOC_LITERAL(8, 129, 10), // "WriteValue"
QT_MOC_LITERAL(9, 140, 5), // "value"
QT_MOC_LITERAL(10, 146, 5), // "Flags"
QT_MOC_LITERAL(11, 152, 9), // "Notifying"
QT_MOC_LITERAL(12, 162, 7), // "Service"
QT_MOC_LITERAL(13, 170, 15), // "QDBusObjectPath"
QT_MOC_LITERAL(14, 186, 4), // "UUID"
QT_MOC_LITERAL(15, 191, 5) // "Value"

    },
    "OrgBluezGattCharacteristic1Interface\0"
    "ReadValue\0QDBusPendingReply<QByteArray>\0"
    "\0options\0StartNotify\0QDBusPendingReply<>\0"
    "StopNotify\0WriteValue\0value\0Flags\0"
    "Notifying\0Service\0QDBusObjectPath\0"
    "UUID\0Value"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_OrgBluezGattCharacteristic1Interface[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       5,   44, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   34,    3, 0x0a /* Public */,
       5,    0,   37,    3, 0x0a /* Public */,
       7,    0,   38,    3, 0x0a /* Public */,
       8,    2,   39,    3, 0x0a /* Public */,

 // slots: parameters
    0x80000000 | 2, QMetaType::QVariantMap,    4,
    0x80000000 | 6,
    0x80000000 | 6,
    0x80000000 | 6, QMetaType::QByteArray, QMetaType::QVariantMap,    9,    4,

 // properties: name, type, flags
      10, QMetaType::QStringList, 0x00095001,
      11, QMetaType::Bool, 0x00095001,
      12, 0x80000000 | 13, 0x00095009,
      14, QMetaType::QString, 0x00095001,
      15, QMetaType::QByteArray, 0x00095001,

       0        // eod
};

void OrgBluezGattCharacteristic1Interface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<OrgBluezGattCharacteristic1Interface *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { QDBusPendingReply<QByteArray> _r = _t->ReadValue((*reinterpret_cast< const QVariantMap(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<QByteArray>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusPendingReply<> _r = _t->StartNotify();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<> _r = _t->StopNotify();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<> _r = _t->WriteValue((*reinterpret_cast< const QByteArray(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDBusObjectPath >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<OrgBluezGattCharacteristic1Interface *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QStringList*>(_v) = _t->flags(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->notifying(); break;
        case 2: *reinterpret_cast< QDBusObjectPath*>(_v) = _t->service(); break;
        case 3: *reinterpret_cast< QString*>(_v) = _t->uUID(); break;
        case 4: *reinterpret_cast< QByteArray*>(_v) = _t->value(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject OrgBluezGattCharacteristic1Interface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_meta_stringdata_OrgBluezGattCharacteristic1Interface.data,
    qt_meta_data_OrgBluezGattCharacteristic1Interface,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *OrgBluezGattCharacteristic1Interface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgBluezGattCharacteristic1Interface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_OrgBluezGattCharacteristic1Interface.stringdata0))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgBluezGattCharacteristic1Interface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 5;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
